@@ -55,6 +55,11 @@
  #define HABITATION_KEY "ht"
  #define FRIENDS_KEY "fr"
  #define IMG_KEY "bp"
+ #define PH_KEY "ph"
+ #define HASH_KEY "hash"
+ #define RHASH_KEY "rhash"
+ #define URL_KEY "url"
+ #define AID_KEY "aid"
 
 //TYPES
 #define TYPE_STRING "string"
@@ -64,17 +69,12 @@
 #define TYPE_SELECT "select"
 #define TYPE_ARRAY "array"
 
-int parser_profile(xmlDocPtr doc, char *json, char* remixmid, gboolean image);
+int parser_profile(xmlDocPtr doc, char *json, char* remixmid, gboolean image, struct ProfileData *cp);
+int parser_profile_albums(xmlDocPtr doc, char* json, char* remixmid, struct ProfileData *cp);
 int parser_image(xmlDocPtr doc, char* data, char* url);
 int parser_friends(char* json, xmlDocPtr doc, int counter);
- 
 int parser_messages(char *json, xmlDocPtr doc, gchar *message_id, int counter, int max_count);
-
-/**
- * Parses json data, form xml
- * @param json - data in json format
- * @return number of new messages
- */
 int parser_new_messages(char* json);
+int parser_photos(char *json, xmlDocPtr doc, int counter);
 int check(char* json);	
 #endif
